@@ -32,15 +32,20 @@ class ResultReceiver(object):
         LOGGER.info(f'[采集结果]开始接收... batch_id={batch_id}')
 
         connection = await aio_pika.connect_robust(self.rabbit_uri)
+        LOGGER.info(f'[采集结果]1. batch_id={batch_id}')
         channel = await connection.channel()
+        LOGGER.info(f'[采集结果]2. batch_id={batch_id}')
         # 服务质量保证，在非自动确认情况下，一定数目的消息没有确认，不进行消费新的消息
-        await channel.set_qos(self.qos)
+        # await channel.set_qos(self.qos)
+        LOGGER.info(f'[采集结果]3. batch_id={batch_id}')
         queue = await channel.declare_queue(
             name=queue_name,
             auto_delete=True,
             arguments={'x-expires': self.queue_expires * 1000}
         )
+        LOGGER.info(f'[采集结果]4. batch_id={batch_id}')
         await channel.declare_exchange(name=exchange_name)
+        LOGGER.info(f'[采集结果]5. batch_id={batch_id}')
         await queue.bind(exchange=exchange_name, routing_key=routing_name)
         LOGGER.info(f'[采集结果]队列信息 queue={queue_name}, exchange={exchange_name}, routing={routing_name}')
 
